==> openshift-model-monitoring-6.1.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ProbeTargetsFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ProbeTargetsFluentImpl<A extends ProbeTargetsFluent<A>> extends BaseFluent<A> implements ProbeTargetsFluent<A>{
  public ProbeTargetsFluentImpl() {
  }
  public ProbeTargetsFluentImpl(ProbeTargets instance) {
    this.withIngress(instance.getIngress()); 
    this.withStaticConfig(instance.getStaticConfig()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ProbeTargetIngressBuilder ingress;
  private ProbeTargetStaticConfigBuilder staticConfig;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildIngress instead.
   * @return The buildable object.
   */
  @Deprecated
  public ProbeTargetIngress getIngress() {
    return this.ingress!=null ?this.ingress.build():null;
  }
  public ProbeTargetIngress buildIngress() {
    return this.ingress!=null ?this.ingress.build():null;
  }
  public A withIngress(ProbeTargetIngress ingress) {
    _visitables.get("ingress").remove(this.ingress);
    if (ingress!=null){ this.ingress= new ProbeTargetIngressBuilder(ingress); _visitables.get("ingress").add(this.ingress);} else { this.ingress = null; _visitables.get("ingress").remove(this.ingress); } return (A) this;
  }
  public Boolean hasIngress() {
    return this.ingress != null;
  }
  public ProbeTargetsFluent.IngressNested<A> withNewIngress() {
    return new ProbeTargetsFluentImpl.IngressNestedImpl();
  }
  public ProbeTargetsFluent.IngressNested<A> withNewIngressLike(ProbeTargetIngress item) {
    return new ProbeTargetsFluentImpl.IngressNestedImpl(item);
  }
  public ProbeTargetsFluent.IngressNested<A> editIngress() {
    return withNewIngressLike(getIngress());
  }
  public ProbeTargetsFluent.IngressNested<A> editOrNewIngress() {
    return withNewIngressLike(getIngress() != null ? getIngress(): new ProbeTargetIngressBuilder().build());
  }
  public ProbeTargetsFluent.IngressNested<A> editOrNewIngressLike(ProbeTargetIngress item) {
    return withNewIngressLike(getIngress() != null ? getIngress(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStaticConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public ProbeTargetStaticConfig getStaticConfig() {
    return this.staticConfig!=null ?this.staticConfig.build():null;
  }
  public ProbeTargetStaticConfig buildStaticConfig() {
    return this.staticConfig!=null ?this.staticConfig.build():null;
  }
  public A withStaticConfig(ProbeTargetStaticConfig staticConfig) {
    _visitables.get("staticConfig").remove(this.staticConfig);
    if (staticConfig!=null){ this.staticConfig= new ProbeTargetStaticConfigBuilder(staticConfig); _visitables.get("staticConfig").add(this.staticConfig);} else { this.staticConfig = null; _visitables.get("staticConfig").remove(this.staticConfig); } return (A) this;
  }
  public Boolean hasStaticConfig() {
    return this.staticConfig != null;
  }
  public ProbeTargetsFluent.StaticConfigNested<A> withNewStaticConfig() {
    return new ProbeTargetsFluentImpl.StaticConfigNestedImpl();
  }
  public ProbeTargetsFluent.StaticConfigNested<A> withNewStaticConfigLike(ProbeTargetStaticConfig item) {
    return new ProbeTargetsFluentImpl.StaticConfigNestedImpl(item);
  }
  public ProbeTargetsFluent.StaticConfigNested<A> editStaticConfig() {
    return withNewStaticConfigLike(getStaticConfig());
  }
  public ProbeTargetsFluent.StaticConfigNested<A> editOrNewStaticConfig() {
    return withNewStaticConfigLike(getStaticConfig() != null ? getStaticConfig(): new ProbeTargetStaticConfigBuilder().build());
  }
  public ProbeTargetsFluent.StaticConfigNested<A> editOrNewStaticConfigLike(ProbeTargetStaticConfig item) {
    return withNewStaticConfigLike(getStaticConfig() != null ? getStaticConfig(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ProbeTargetsFluentImpl that = (ProbeTargetsFluentImpl) o;
    if (ingress != null ? !ingress.equals(that.ingress) :that.ingress != null) return false;
    if (staticConfig != null ? !staticConfig.equals(that.staticConfig) :that.staticConfig != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ingress,  staticConfig,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (ingress != null) { sb.append("ingress:"); sb.append(ingress + ","); }
    if (staticConfig != null) { sb.append("staticConfig:"); sb.append(staticConfig + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class IngressNestedImpl<N> extends ProbeTargetIngressFluentImpl<ProbeTargetsFluent.IngressNested<N>> implements ProbeTargetsFluent.IngressNested<N>,Nested<N>{
    IngressNestedImpl(ProbeTargetIngress item) {
      this.builder = new ProbeTargetIngressBuilder(this, item);
    }
    IngressNestedImpl() {
      this.builder = new ProbeTargetIngressBuilder(this);
    }
    ProbeTargetIngressBuilder builder;
    public N and() {
      return (N) ProbeTargetsFluentImpl.this.withIngress(builder.build());
    }
    public N endIngress() {
      return and();
    }
    
  }
  class StaticConfigNestedImpl<N> extends ProbeTargetStaticConfigFluentImpl<ProbeTargetsFluent.StaticConfigNested<N>> implements ProbeTargetsFluent.StaticConfigNested<N>,Nested<N>{
    StaticConfigNestedImpl(ProbeTargetStaticConfig item) {
      this.builder = new ProbeTargetStaticConfigBuilder(this, item);
    }
    StaticConfigNestedImpl() {
      this.builder = new ProbeTargetStaticConfigBuilder(this);
    }
    ProbeTargetStaticConfigBuilder builder;
    public N and() {
      return (N) ProbeTargetsFluentImpl.this.withStaticConfig(builder.build());
    }
    public N endStaticConfig() {
      return and();
    }
    
  }
  
}

==> openshift-model-monitoring-6.7.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ProbeTargetsFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ProbeTargetsFluentImpl<A extends ProbeTargetsFluent<A>> extends BaseFluent<A> implements ProbeTargetsFluent<A>{
  public ProbeTargetsFluentImpl() {
  }
  public ProbeTargetsFluentImpl(ProbeTargets instance) {
    if (instance != null) {
      this.withIngress(instance.getIngress());
      this.withStaticConfig(instance.getStaticConfig());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ProbeTargetIngressBuilder ingress;
  private ProbeTargetStaticConfigBuilder staticConfig;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildIngress instead.
   * @return The buildable object.
   */
  @Deprecated
  public ProbeTargetIngress getIngress() {
    return this.ingress!=null ?this.ingress.build():null;
  }
  public ProbeTargetIngress buildIngress() {
    return this.ingress!=null ?this.ingress.build():null;
  }
  public A withIngress(ProbeTargetIngress ingress) {
    _visitables.get("ingress").remove(this.ingress);
    if (ingress!=null){ this.ingress= new ProbeTargetIngressBuilder(ingress); _visitables.get("ingress").add(this.ingress);} else { this.ingress = null; _visitables.get("ingress").remove(this.ingress); } return (A) this;
  }
  public Boolean hasIngress() {
    return this.ingress != null;
  }
  public ProbeTargetsFluentImpl.IngressNested<A> withNewIngress() {
    return new ProbeTargetsFluentImpl.IngressNestedImpl();
  }
  public ProbeTargetsFluentImpl.IngressNested<A> withNewIngressLike(ProbeTargetIngress item) {
    return new ProbeTargetsFluentImpl.IngressNestedImpl(item);
  }
  public ProbeTargetsFluentImpl.IngressNested<A> editIngress() {
    return withNewIngressLike(getIngress());
  }
  public ProbeTargetsFluentImpl.IngressNested<A> editOrNewIngress() {
    return withNewIngressLike(getIngress() != null ? getIngress(): new ProbeTargetIngressBuilder().build());
  }
  public ProbeTargetsFluentImpl.IngressNested<A> editOrNewIngressLike(ProbeTargetIngress item) {
    return withNewIngressLike(getIngress() != null ? getIngress(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStaticConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public ProbeTargetStaticConfig getStaticConfig() {
    return this.staticConfig!=null ?this.staticConfig.build():null;
  }
  public ProbeTargetStaticConfig buildStaticConfig() {
    return this.staticConfig!=null ?this.staticConfig.build():null;
  }
  public A withStaticConfig(ProbeTargetStaticConfig staticConfig) {
    _visitables.get("staticConfig").remove(this.staticConfig);
    if (staticConfig!=null){ this.staticConfig= new ProbeTargetStaticConfigBuilder(staticConfig); _visitables.get("staticConfig").add(this.staticConfig);} else { this.staticConfig = null; _visitables.get("staticConfig").remove(this.staticConfig); } return (A) this;
  }
  public Boolean hasStaticConfig() {
    return this.staticConfig != null;
  }
  public ProbeTargetsFluentImpl.StaticConfigNested<A> withNewStaticConfig() {
    return new ProbeTargetsFluentImpl.StaticConfigNestedImpl();
  }
  public ProbeTargetsFluentImpl.StaticConfigNested<A> withNewStaticConfigLike(ProbeTargetStaticConfig item) {
    return new ProbeTargetsFluentImpl.StaticConfigNestedImpl(item);
  }
  public ProbeTargetsFluentImpl.StaticConfigNested<A> editStaticConfig() {
    return withNewStaticConfigLike(getStaticConfig());
  }
  public ProbeTargetsFluentImpl.StaticConfigNested<A> editOrNewStaticConfig() {
    return withNewStaticConfigLike(getStaticConfig() != null ? getStaticConfig(): new ProbeTargetStaticConfigBuilder().build());
  }
  public ProbeTargetsFluentImpl.StaticConfigNested<A> editOrNewStaticConfigLike(ProbeTargetStaticConfig item) {
    return withNewStaticConfigLike(getStaticConfig() != null ? getStaticConfig(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ProbeTargetsFluentImpl that = (ProbeTargetsFluentImpl) o;
    if (!java.util.Objects.equals(ingress, that.ingress)) return false;

    if (!java.util.Objects.equals(staticConfig, that.staticConfig)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ingress,  staticConfig,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (ingress != null) { sb.append("ingress:"); sb.append(ingress + ","); }
    if (staticConfig != null) { sb.append("staticConfig:"); sb.append(staticConfig + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class IngressNestedImpl<N> extends ProbeTargetIngressFluentImpl<ProbeTargetsFluentImpl.IngressNested<N>> implements ProbeTargetsFluentImpl.IngressNested<N>,Nested<N>{
    IngressNestedImpl(ProbeTargetIngress item) {
      this.builder = new ProbeTargetIngressBuilder(this, item);
    }
    IngressNestedImpl() {
      this.builder = new ProbeTargetIngressBuilder(this);
    }
    ProbeTargetIngressBuilder builder;
    public N and() {
      return (N) ProbeTargetsFluentImpl.this.withIngress(builder.build());
    }
    public N endIngress() {
      return and();
    }
    
  }
  class StaticConfigNestedImpl<N> extends ProbeTargetStaticConfigFluentImpl<ProbeTargetsFluentImpl.StaticConfigNested<N>> implements ProbeTargetsFluentImpl.StaticConfigNested<N>,Nested<N>{
    StaticConfigNestedImpl(ProbeTargetStaticConfig item) {
      this.builder = new ProbeTargetStaticConfigBuilder(this, item);
    }
    StaticConfigNestedImpl() {
      this.builder = new ProbeTargetStaticConfigBuilder(this);
    }
    ProbeTargetStaticConfigBuilder builder;
    public N and() {
      return (N) ProbeTargetsFluentImpl.this.withStaticConfig(builder.build());
    }
    public N endStaticConfig() {
      return and();
    }
    
  }
  
}
